@@ -6,14 +6,15 @@
 
 Usage:
   exo [options] read [--follow] [--limit=<limit>] [--selection=all|autowindow|givenwindow] <cik> <rid>
-  exo [options] write <cik> <rid> <value>
+  exo [options] write <cik> <rid> --value=<value>
   exo [options] create-dataport <cik> (--format=binary|boolean|float|integer|string) [--name=<name>]
   exo [options] create-client <cik> [--name=<name>]
   exo [options] map <cik> <rid> <alias>
   exo [options] drop <cik> <rid> ...
   exo [options] listing [--plain] <cik> (--type=client|dataport|datarule|dispatch) ...
   exo [options] info <cik> <rid> [--cikonly] 
-  exo [options] tree <cik> [--show-rid] [--show-aliases]
+  exo [options] flush <cik> <rid>
+  exo [options] tree <cik> [--show-rid] [--show-aliases] [--show-units]
   exo [options] lookup-rid <cik> <cik-to-find>
   exo [options] drop-all-children <cik>
 
@@ -34,6 +35,7 @@ import csv
 from datetime import datetime
 import time
 from pprint import pprint
+from collections import OrderedDict
 
 from docopt import docopt
 from onepv1lib import onep
@@ -136,30 +138,42 @@ class ExoRPC():
         else:
             return response
 
+    def flush(self, cik, rid):
+        self.exo.flush(cik, rid)
+
     def _print_node(self, rid, info, aliases, cli_args, spacer, islast):
         typ = info['basic']['type']
         id = 'cik: ' + info['key'] if typ=='client' else 'rid: ' + rid
         name = info['description']['name']
+        try:
+            # Units are a portals only thing
+            # u'comments': [[u'public', u'{"unit":"Fahrenheit"}']],']]
+            units = json.loads(info['comments'][0][1])['unit']
+            if len(units.strip()) == 0:
+                units = 'none'
+        except:
+            units = 'none'
 
-        # This is strange. Sometimes aliases is a dict, sometimes a list.
+        # Sometimes aliases is a dict, sometimes a list. TODO: Why?
         # Translate it into a list. 
         if type(aliases) is dict:
             aliases = aliases.get(rid, [])
         elif aliases is None:
             aliases = []
 
-        opt = {}
+        opt = OrderedDict()
         def add_opt(o, label, value):
-            if cli_args.has_key(o) and cli_args[o] == True:
+            if o is True or (cli_args.has_key(o) and cli_args[o] == True):
                 opt[label] = value
-        add_opt('--show-rid', 'rid', rid)
+        add_opt(True, 'type', typ)
+        add_opt(True, 'name', name)
         add_opt('--show-aliases', 'aliases', 'none' if len(aliases) == 0 else ', '.join(aliases))
+        add_opt('--show-rid', 'rid', rid)
+        add_opt('--show-units', 'units', units)
         
-        print('{}{} type: {} name: {} {}'.format(
+        print('{}{} {}'.format(
             spacer,
             id,
-            typ,
-            name,            
             '' if len(opt) == 0 else '({})'.format(', '.join(
                 ['{}: {}'.format(k, v) for k, v in opt.iteritems()]))))
 
@@ -194,10 +208,11 @@ class ExoRPC():
                     self._print_node(rid, info, aliases, cli_args, new_spacer + indent_spacer, islast)
                    
     def drop_all_children(self, cik):
-        isok, listing = self.exo.listing(cik, types=['client'])
+        isok, listing = self.exo.listing(cik, types=['client', 'dataport', 'datarule', 'dispatch'])
         self._raise_for_response(isok, listing)
 
-        self.drop(cik, listing[0])
+        for l in listing:
+            self.drop(cik, l)
 
     def lookup_rid(self, cik, cik_to_find):
         isok, listing = self.exo.listing(cik, types=['client'])
@@ -230,7 +245,6 @@ def handle_args(args):
     if args['read']:
         rid = args['<rid>'][0]
         limit = args['--limit']
-        print("limit {}".format(limit))
         limit = 1 if limit is None else int(limit)
         dr = csv.DictWriter(sys.stdout, ['timestamp', 'value'])
         def printline(timestamp, val):
@@ -264,7 +278,7 @@ def handle_args(args):
                                 limit=limit):
                 printline(t, v)
     elif args['write']:
-        er.write(cik, args['<rid>'][0], args['<value>'])
+        er.write(cik, args['<rid>'][0], args['--value'])
     elif args['create-dataport']:
         pr(er.create_dataport(cik, args['--format'], name=args['--name']))
     elif args['create-client']:
@@ -285,6 +299,8 @@ def handle_args(args):
             pr(listing)
     elif args['info']:
         pr(er.info(cik, args['<rid>'][0], cikonly=args['--cikonly']))
+    elif args['flush']:
+        er.flush(cik, args['<rid>'])
     # special commands
     elif args['tree']:
         er.tree(cik, cli_args=args)
